/**
 * Copyright (C) 2013-2017 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 2 as publishedby the Free
 * Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of the
 * following licenses, the combination of the program with the linked library is
 * not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed under
 * the aforementioned licenses, is permitted by the copyright holders if the
 * distribution is compliant with both the GNU General Public License version 2
 * and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 */
package org.n52.io.style;

import org.n52.io.v1.data.StyleProperties;


public class BarStyle extends Style {

	private static final String BAR_INTERVAL = "interval";
	
	private static final String BAR_WIDTH = "width";
    
	private static final String DEFAULT_BAR_INTERVAL = "byDay";
	
	private static final double DEFAULT_BAR_WIDTH = 0.8;
    
    public String getBarInterval() {
    	if (hasProperty(BAR_INTERVAL)) {
    		return getPropertyAsString(BAR_INTERVAL);
    	}
    	return DEFAULT_BAR_INTERVAL;
    }
    
    public double getBarMargin() {
    	// API parameter width is more intuitive than margin parameter internally used by jFreeChart 
		if (hasProperty(BAR_WIDTH)) {
			return 1.0 - getPropertyAsDouble(BAR_WIDTH);
		}
		return DEFAULT_BAR_WIDTH;
	}
    
    public static BarStyle createBarStyle(StyleProperties options) {
        if (options == null || options.getProperties().isEmpty()) {
            return createDefaultBarStyle();
        }
        BarStyle barStyleOptions = new BarStyle();
        barStyleOptions.setProperties(options.getProperties());
        return barStyleOptions;
    }

    public static BarStyle createDefaultBarStyle() {
        return new BarStyle();
    }
    
}
